#ifndef NT2_INCLUDE_FUNCTIONS_ELLIK_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ELLIK_HPP_INCLUDED

#include <nt2/elliptic/include/functions/ellik.hpp>

#endif
